from pyeasyphd.scripts.run_article_md import run_article_md_daily_notes

if __name__ == "__main__":
    path_json = ""
    zotero_bib = ""
    path_input_file = ""
    path_output_file = ""
    options = {}

    mcmc_filenames = ["MCMC/Introduction.md", "MCMC/Algorithms.md", "MCMC/Metrics.md", "MCMC/Applications.md"]

    for filenames in [mcmc_filenames]:
        run_article_md_daily_notes(path_input_file, filenames, path_output_file, zotero_bib, path_json, options)



from local_config import local_options

from pyeasyphd.scripts import run_replace_to_standard_cite_keys

if __name__ == "__main__":
    path_output = local_options["path_output"]
    path_conf_j_jsons = local_options["path_conf_j_jsons"]

    options = {}

    full_md = "/path/to/full.md"
    full_bib = "/path/to/full.bib"
    run_replace_to_standard_cite_keys(full_md, full_bib, path_output, path_conf_j_jsons, options)
